@@ -350,19 +350,13 @@ void TwitterApiMicroBlog::repeatPost(Choqok::Account* theAccount, const ChoqokId
     KUrl url = account->apiUrl();
     url.addPath ( QString("/statuses/retweet/%1.%2").arg(postId).arg(format) );
     QByteArray data;
-    QOAuth::ParamMap params;
-    if(account->usingOAuth()){
-        params.insert("source","choqok");
-    } else {
-        data = "source=choqok";
-    }
     KIO::StoredTransferJob *job = KIO::storedHttpPost ( data, url, KIO::HideProgressInfo ) ;
     if ( !job ) {
         kDebug() << "Cannot create an http POST request!";
         return;
     }
     job->addMetaData ( "content-type", "Content-Type: application/x-www-form-urlencoded" );
-    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url, QOAuth::POST, params));
+    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url, QOAuth::POST));
     Choqok::Post *post = new Choqok::Post;
     post->postId = postId;
     mCreatePostMap[ job ] = post;
@@ -816,7 +810,7 @@ QByteArray TwitterApiMicroBlog::authorizationHeader(TwitterApiAccount* theAccoun
                                                              theAccount->oauthTokenSecret(), QOAuth::HMAC_SHA1,
                                                              params, QOAuth::ParseForHeaderArguments );
     } else {
-        auth = theAccount->username().toUtf8() + ":" + theAccount->password().toUtf8();
+        auth = theAccount->username().toUtf8() + ':' + theAccount->password().toUtf8();
         auth = auth.toBase64().prepend( "Basic " );
     }
     return auth;
@@ -836,7 +830,9 @@ Choqok::Post * TwitterApiMicroBlog::readPostFromXml ( Choqok::Account* theAccoun
             kError()<<"TwitterApiMicroBlog::readPostFromXml: post is NULL!";
             post = new Choqok::Post;
         }
-        Q_EMIT error(theAccount, ServerError, checkXmlForError(buffer));
+        QString err = checkXmlForError(buffer);
+        if(!err.isEmpty())
+            Q_EMIT error(theAccount, ServerError, err);
         post->isError = true;
         return post;
     }
@@ -927,7 +923,9 @@ QList<Choqok::Post*> TwitterApiMicroBlog::readTimelineFromXml ( Choqok::Account*
     if ( root.tagName() != "statuses" ) {
         //         QString err = i18n( "Data returned from server is corrupted." );
         kDebug() << "there's no statuses tag in XML\t the XML is: \n" << buffer;
-        Q_EMIT error(theAccount, ServerError, checkXmlForError(buffer));
+        QString err = checkXmlForError(buffer);
+        if(!err.isEmpty())
+            Q_EMIT error(theAccount, ServerError, err);
         return postList;
     }
     QDomNode node = root.firstChild();
@@ -949,7 +947,9 @@ Choqok::Post * TwitterApiMicroBlog::readDMessageFromXml (Choqok::Account *theAcc
     } else {
         Choqok::Post *post = new Choqok::Post;
         post->isError = true;
-        Q_EMIT error(theAccount, ServerError, checkXmlForError(buffer));
+        QString err = checkXmlForError(buffer);
+        if(!err.isEmpty())
+            Q_EMIT error(theAccount, ServerError, err);
         return post;
     }
 }
@@ -1048,7 +1048,9 @@ QList<Choqok::Post*> TwitterApiMicroBlog::readDMessagesFromXml (Choqok::Account
     if ( root.tagName() != "direct-messages" ) {
         //         QString err = i18n( "Data returned from server is corrupted." );
         kDebug() << "there's no statuses tag in XML\t the XML is: \n" << buffer.data();
-        Q_EMIT error(theAccount, ServerError, checkXmlForError(buffer));
+        QString err = checkXmlForError(buffer);
+        if(!err.isEmpty())
+            Q_EMIT error(theAccount, ServerError, err);
         return postList;
     }
     QDomNode node = root.firstChild();
