@@ -79,7 +79,26 @@ const QString PostWidget::baseStyle ("KTextBrowser {border: 1px solid rgb(150,15
 border-radius:5px;}  KTextBrowser {color:%1; background-color:%2}\
 KPushButton{border:0px}");
 
-const QRegExp PostWidget::mUrlRegExp("((https?://|ftp://|www\\.)[^\\s<>\"]+[^!,\\.\\s<>'\"\\)\\]])");
+// Can't validate domains with national symbols
+const QString protocols = "((https?|ftps?)://)";
+const QString subdomains = "(([\\S]\\.)?)";
+const QString auth = "((([\\S]{1,})((:[\\S]{1,})?)@)?)";
+const QString domains = "([a-z0-9-]{1,63}\\.)+";
+const QString port = "(:(6553[0-5]|655[0-2][0-9]|65[0-4][\\d]{2}|6[0-4][\\d]{3}|[1-5][\\d]{4}|[1-9][\\d]{0,3})[\\D])";
+const QString zone ("((a(c|d|e|f|g|i|l|m|n|o|q|r|s|t|u|w|x|z))|(b(a|b|d|e|f|g|h|i|j|l|m|n|o|r|s|t|v|w|y|z))|(c(a|c|d|f|g|h|i|k|l|m|n|o|r|u|v|x|y|z))|\
+(d(e|j|k|m|o|z))|(e(c|e|g|h|r|s|t|u))|(f(i|j|k|m|o|r))|(g(a|b|d|e|f|g|h|i|l|m|n|p|q|r|s|t|u|w|y))|(h(k|m|n|r|t|u))|(i(d|e|l|m|n|o|q|r|s|t))|\
+(j(e|m|o|p))|(k(e|g|h|i|m|n|p|r|w|y|z))|(l(a|b|c|i|k|r|s|t|u|v|y))|(m(a|c|d|e|f|g|h|k|l|m|n|o|p|q|r|s|t|u|v|w|x|y|z))|(n(a|c|e|f|g|i|l|o|p|r|u|z))|\
+(om)|(p(a|e|f|g|h|k|l|n|r|s|t|w|y))|(qa)|(r(e|o|s|u|w))|(s(a|b|c|d|e|g|h|i|j|k|l|m|n|o|r|t|u|v|y|z))|(t(c|d|f|g|h|j|k|m|n|o|p|r|t|v|w|z))|\
+(u(a|g|k|s|y|z))|(v(a|c|e|g|i|n|u))|(w(f|s))|(ye)|(z(a|m|r|w))|(asia|com|info|net|org|biz|name|pro|aero|cat|coop|edu|jobs|mobi|museum|tel|travel|gov|int|mil|local))");
+const QString ip = "(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})(\\.(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})){3}";
+const QString params = "(((\\/)[\\w:/\\?#\\[\\]@!\\$&\\(\\)\\*%\\+,;=\\._~-]{1,}|%[0-9a-f]{2})?)";
+
+const QRegExp PostWidget::mUrlRegExp("((((" + protocols + "?)" + auth +
+                          subdomains +
+                          "((" + domains +               
+                          zone + "(?!(\\w)))|((to|ai)\\.)))|(" + protocols + '(' + ip + ")+))" +
+                          '(' + port + "?)" + "((\\/)?)"  +
+                          params + ')', Qt::CaseInsensitive);
 
 QString PostWidget::readStyle;
 QString PostWidget::unreadStyle;
@@ -89,7 +108,7 @@ const QString PostWidget::webIconText("&#9755;");
 PostWidget::PostWidget( Account* account, const Choqok::Post& post, QWidget* parent/* = 0*/ )
     :QWidget(parent), _mainWidget(new TextBrowser(this)), d(new Private(account, post))
 {
-    setAttribute(Qt::WA_DeleteOnClose);
+//     setAttribute(Qt::WA_DeleteOnClose);
     if(currentAccount()->username().compare( currentPost().author.userName, Qt::CaseInsensitive ) == 0 )
         d->mCurrentPost.isRead = true;
     d->mTimer.start( _MINUTE );
@@ -158,7 +177,8 @@ void PostWidget::initUi()
     _mainWidget->document()->addResource( QTextDocument::ImageResource, QUrl("img://profileImage"),
                              MediaManager::self()->defaultImage() );
 
-    if(d->mCurrentAccount->username().compare( d->mCurrentPost.author.userName, Qt::CaseInsensitive ) == 0) {
+    if(d->mCurrentAccount->username().compare( d->mCurrentPost.author.userName, Qt::CaseInsensitive ) == 0
+        || currentPost().isPrivate) {
         KPushButton *btnRemove = addButton("btnRemove", i18nc( "@info:tooltip", "Remove" ), "edit-delete" );
         connect(btnRemove, SIGNAL(clicked(bool)), SLOT(removeCurrentPost()));
         baseText = &ownText;
@@ -281,7 +301,8 @@ void PostWidget::closeEvent(QCloseEvent* event)
 {
 //     kDebug();
     Q_EMIT aboutClosing(currentPost().postId, this);
-    event->accept();
+    event->ignore();
+    QWidget::deleteLater();
 }
 
 void PostWidget::mousePressEvent(QMouseEvent* ev)
@@ -317,18 +338,21 @@ void PostWidget::leaveEvent ( QEvent * event )
 QString PostWidget::prepareStatus( const QString &txt )
 {
     QString text = txt;
+    text.replace( "&amp;", "&amp;amp;" );
     text.replace( '<', "&lt;" );
     text.replace( '>', "&gt;" );
     int pos = 0;
     while(((pos = mUrlRegExp.indexIn(text, pos)) != -1)) {
         QString link = mUrlRegExp.cap(0);
+        text.remove( pos, link.length() );
         QString tmplink = link;
-        if (tmplink.startsWith("www.", Qt::CaseInsensitive))
-            tmplink.prepend("http://");
+        if ( !tmplink.startsWith(QLatin1String("http"), Qt::CaseInsensitive) &&
+             !tmplink.startsWith(QLatin1String("ftp"), Qt::CaseInsensitive) )
+             tmplink.prepend("http://");
         static const QString hrefTemplate("<a href='%1' title='%1' target='_blank'>%2</a>");
-        tmplink = hrefTemplate.arg(tmplink, link);
-        text.replace(pos, link.length(), tmplink);
-        pos += tmplink.count();
+        tmplink = hrefTemplate.arg( tmplink, link );
+        text.insert( pos, tmplink );
+        pos += tmplink.length();
     }
 
     if(AppearanceSettings::isEmoticonsEnabled())
@@ -418,15 +442,15 @@ void PostWidget::slotResendPost()
 
 QString PostWidget::generateResendText()
 {
-	if (BehaviorSettings::useCustomRT())
-	{
-		return QString(BehaviorSettings::customRT()) + " @" + currentPost().author.userName + ": " + currentPost().content;
-	}
-	else
-	{
-		QChar re(0x267B);
-		return QString(re) + " @" + currentPost().author.userName + ": " + currentPost().content;
-	}
+    if (BehaviorSettings::useCustomRT())
+    {
+        return QString(BehaviorSettings::customRT()) + " @" + currentPost().author.userName + ": " + currentPost().content;
+    }
+    else
+    {
+        QChar re(0x267B);
+        return QString(re) + " @" + currentPost().author.userName + ": " + currentPost().content;
+    }
 }
 
 void PostWidget::setupAvatar()
